@@ -429,7 +429,7 @@ class TestCTFont (TestCase):
         self.assertIsInstance(v, CTFontRef)
 
 
-    @expectedFailureIf(os_release() == '10.6')
+    @expectedFailureIf(os_release().rsplit('.', 1)[0] == '10.6')
     @min_os_level('10.6')
     def testFunctions10_6_crash(self):
         descr = CTFontDescriptorCreateWithNameAndSize(
@@ -439,7 +439,7 @@ class TestCTFont (TestCase):
         self.assertResultIsCFRetained(CTFontCreateWithFontDescriptorAndOptions)
 
         # FIXME: this crashes the interpreter, without a clear reason
-        if os_release() == '10.6':
+        if os_release().rsplit('.', 1)[0] == '10.6':
             self.fail("hard crash in test for CTFontCreateWithFontDescriptorAndOptions")
         v = CTFontCreateWithFontDescriptorAndOptions(descr, 14.0, None, 0)
         self.assertIsInstance(v, CTFontRef)
